@@ -1,3 +1,5 @@
+# $Id: Sitebase.pm,v 1.3 2007/07/25 19:19:04 grant Exp $
+
 package WWW::Sitebase;
 
 use Spiffy -Base;
@@ -12,28 +14,25 @@ WWW::Sitebase - Base class for Perl modules
 
 =head1 VERSION
 
-Version 0.15
+Version 0.2
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.2';
 
 =head1 SYNOPSIS
 
+(Derived from WWW::Myspace::MyBase 0.3)
+
 This is a base class that can be used for all Perl modules.
 I could probably call it "Base" or somesuch, but that's a bit
 too presumptious for my taste, so I just included it here.
 You'll probably just use WWW::Sitebase::Navigator or WWW::Sitebase::Poster
 instead, which subclass WWW::Sitebase.
 WWW::Sitebase provides basic, standardized options parsing
-in several formats. It validates data using Params::Validate, provides clean
-OO programming using Spiffy, and reads config files using Config::General.
-It gives your module a powerful "new" method that automatically
-takes any fields your module supports as arguments or reads them from a
-config file.  It also provides your module with "save" and "load" methods.
+in several formats. It validates data using Params::Validate.
 
-
-To use this to write your new module, you simply subclass this module, add
+To use this in your new module, you simply subclass this module, add
 the "default_options" method to define your data, and write your methods.
 
  package WWW::MySite::MyModule;
@@ -58,17 +57,6 @@ the "default_options" method to define your data, and write your methods.
  or
  
  $object = new WWW::MySite::MyModule( { happiness => 5 } );
- 
- They can save their object to disk:
- $object->save( $filename );
- 
- And read it back:
- $object = new WWW::MySite::MyModule();
- $object->load( $filename );
- 
- or since "save" writes a YAML file:
- $object = new WWW::MySite::MyModule(
-    'config_file' => $filename, 'config_file_format' => 'YAML' );
 
 See Params::Validate for more info on the format of, and available
 parsing stunts available in, default_options.
@@ -94,22 +82,14 @@ values.  The format is such that it can be passed to Params::Validate
 (and, well it is :).
 
 You MUST override this method to return your default options.
-Basically, you just have to do this:
+Fortunately we use Spiffy, so you just have
+to do this:
 
- sub default_options {
+ const default_options => {
+ 		option => { default => value },
+ 		option => { default => value },
+ };
  
-    $self->{default_options}={
- 		option => { default => value },
- 		option => { default => value },
-    };
-    
-    return $self->{default_options};
-
- }
-
-The approach above lets your subclasses add more options if they need to.
-it also sets the default_options parameter, and returns it so that
-you can call $self->default_options instead of $self->{default_options}.
 
 =cut
 
@@ -224,7 +204,7 @@ If called with no arguments, returns a list of all options and
 their values (as option => value pairs).
 
 This is basically a "catch all" accessor method that allows you to be
-lazy and not create accessors for your options.
+lazy ad not create accessors for your options.
 
 =cut
 
@@ -273,13 +253,13 @@ sub parse_options {
 
 	# figure out the format
 	# - new( $options_hashref )
-    if ( ( @_ == 1 ) && ( ref $_[0] eq 'HASH') ) {
+	if ( ( @_ == 1 ) && ( ref $_[0] eq 'HASH') ) {
 		%options = %{ $_[0] };
 	# - new( %options )
 	#   If more than 1 argument, and an even number of arguments, and
 	#   the first argument is one of our known options.
 	} elsif ( ( @_ > 1 ) && ( @_ % 2 == 0 ) &&
-		( defined( $self->default_options->{ "$_[0]" } ) ) ) {
+		( defined( $self->default_options->{$_[0]} ) ) ) {
 		%options = ( @_ );
 	# - new( @options )
 	#   We just assign them in order.
@@ -348,7 +328,6 @@ positional_parameters methods.
 
 sub save {
 
-    my $filename = shift;
 	my $data = {};
 
 	# For each field listed as persistent, store it in the
@@ -364,7 +343,7 @@ sub save {
 		}
 	}
 
-	DumpFile( $filename, $data );
+	DumpFile( $data );
 
 }
 
@@ -428,8 +407,8 @@ Grant Grueninger, C<< <grantg at cpan.org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-www-Sitebase at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Sitebase>.
+C<bug-www-bebo at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Bebo>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -447,7 +426,7 @@ We probably want to include cache_dir and possibile cache_file methods here.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc WWW::Sitebase
+    perldoc WWW::Bebo::Base
 
 You can also look for information at:
 
@@ -455,19 +434,19 @@ You can also look for information at:
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/WWW-Sitebase>
+L<http://annocpan.org/dist/WWW-Bebo>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/WWW-Sitebase>
+L<http://cpanratings.perl.org/d/WWW-Bebo>
 
 =item * RT: CPAN's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Sitebase>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Bebo>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/WWW-Sitebase>
+L<http://search.cpan.org/dist/WWW-Bebo>
 
 =back
 
@@ -475,11 +454,11 @@ L<http://search.cpan.org/dist/WWW-Sitebase>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005, 2014 Grant Grueninger, all rights reserved.
+Copyright 2005 Grant Grueninger, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
-1; # End of WWW::Sitebase
+1; # End of WWW::Bebo::Base
